Lesson Plan
===========


Day 1
-----


Topics
......

- Statements: print, assignment, if/elif/else, while, import, try/except, for, def
- Data types: int, float, bool, str
- Functions: help, type, dir, int, str


Games
.....

- guess.py
- paint.py
- snake.py


Passage
.......

- Genesis 1 - God the Creator


Day 2
-----


Topics
......

- Statements: print, assignment, if/elif/else, while, import, try/except, for, def
- Data types: int, float, bool, str
- Functions: 


Games
.....

- crypto.py
- tictactoe.py
- memory.py


Passage
.......

- Genesis 6-9 - God the Engineer (Noah)


Day 3
-----


Topics
......

- Data types: list, dict


Games
.....

- bagels.py
- connect.py
- simonsays.py


Day 4
-----


Topics
......

- Data types: vector


Games
.....

- bounce.py
- pong.py
- tiles.py


Passage
.......
